@@ -69,9 +69,6 @@ Algorithm::Easing::Bounce - Calculate eased translations between two positive wh
 =cut
 
 =head1 SYNOPSIS
-
-        ## with mediator
-
         use Algorithm::Easing;
         use Algorithm::Easing::Bounce;
 
@@ -117,7 +114,7 @@ Algorithm::Easing::Bounce - Calculate eased translations between two positive wh
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_none($t,$b,$c,$d);
 
 This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
 
@@ -134,9 +131,9 @@ This method is used for a linear translation between two positive real whole int
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_in($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an inward tween using a positive real integer as the parameter for time.
+This method is used to ease in between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in the fashion of a bounce.
 
 =cut
 
@@ -151,9 +148,9 @@ This method is used for a eased translation between two positive real whole inte
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_out($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an outward tween using a positive real integer as the parameter for time.
+This method is used to ease out between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in the fashion of a bounce.
 
 =cut
 
@@ -170,7 +167,7 @@ This method is used for a eased translation between two positive real whole inte
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an inward then outward tween using a positive real integer as the parameter for time.
+This method is used to ease both in then out between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in the fashion of a bounce.
 
 =cut
 
