@@ -59,8 +59,6 @@ Algorithm::Easing::Circular - Calculate eased translations between two positive
 
 =head1 SYNOPSIS
 
-        ## with mediator
-
         use Algorithm::Easing;
         use Algorithm::Easing::Circular;
 
@@ -106,7 +104,7 @@ Algorithm::Easing::Circular - Calculate eased translations between two positive
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_none($t,$b,$c,$d);
 
 This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
 
@@ -123,9 +121,9 @@ This method is used for a linear translation between two positive real whole int
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_in($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an inward tween using a positive real integer as the parameter for time.
+This method is used to ease in between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in a circular fashion.
 
 =cut
 
@@ -140,9 +138,9 @@ This method is used for a eased translation between two positive real whole inte
         Return :
             p = position,
             
-        my $p = $obj->ease_both($t,$b,$c,$d);
+        my $p = $obj->ease_out($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an outward tween using a positive real integer as the parameter for time.
+This method is used to ease out between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in circular fashion.
 
 =cut
 
@@ -159,7 +157,7 @@ This method is used for a eased translation between two positive real whole inte
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
-This method is used for a eased translation between two positive real whole integers as an inward then outward tween using a positive real integer as the parameter for time.
+This method is used to ease both in then out between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in circular fashion.
 
 =cut
 
